@@ -14,3 +14,7 @@ SAM_LOCAL_ENV: str = "AWS_SAM_LOCAL"
 CHALICE_LOCAL_ENV: str = "AWS_CHALICE_CLI_MODE"
 SERVICE_NAME_ENV: str = "POWERTOOLS_SERVICE_NAME"
 XRAY_TRACE_ID_ENV: str = "_X_AMZN_TRACE_ID"
+
+
+XRAY_SDK_MODULE = "aws_xray_sdk"
+XRAY_SDK_CORE_MODULE = "aws_xray_sdk.core"
