@@ -1,6 +1,9 @@
+from aws_lambda_powertools.utilities.data_classes.appsync_resolver_event import AppSyncResolverEvent
+
 from .alb_event import ALBEvent
 from .api_gateway_proxy_event import APIGatewayProxyEvent, APIGatewayProxyEventV2
 from .cloud_watch_logs_event import CloudWatchLogsEvent
+from .connect_contact_flow_event import ConnectContactFlowEvent
 from .dynamo_db_stream_event import DynamoDBStreamEvent
 from .event_bridge_event import EventBridgeEvent
 from .kinesis_stream_event import KinesisStreamEvent
@@ -12,8 +15,10 @@ from .sqs_event import SQSEvent
 __all__ = [
     "APIGatewayProxyEvent",
     "APIGatewayProxyEventV2",
+    "AppSyncResolverEvent",
     "ALBEvent",
     "CloudWatchLogsEvent",
+    "ConnectContactFlowEvent",
     "DynamoDBStreamEvent",
     "EventBridgeEvent",
     "KinesisStreamEvent",
