@@ -10,6 +10,8 @@ from uuid import uuid4
 import boto3
 from botocore.config import Config
 
+from ...shared import constants
+from ...shared.functions import resolve_env_var_choice
 from .base import DEFAULT_PROVIDERS, BaseProvider
 
 CLIENT_ID = str(uuid4())
@@ -33,6 +35,7 @@ class AppConfigProvider(BaseProvider):
     **Retrieves the latest configuration value from App Config**
 
         >>> from aws_lambda_powertools.utilities import parameters
+        >>>
         >>> appconf_provider = parameters.AppConfigProvider(environment="my_env", application="my_app")
         >>>
         >>> value : bytes = appconf_provider.get("my_conf")
@@ -66,7 +69,9 @@ class AppConfigProvider(BaseProvider):
 
         config = config or Config()
         self.client = boto3.client("appconfig", config=config)
-        self.application = application or os.getenv("POWERTOOLS_SERVICE_NAME") or "application_undefined"
+        self.application = resolve_env_var_choice(
+            choice=application, env=os.getenv(constants.SERVICE_NAME_ENV, "service_undefined")
+        )
         self.environment = environment
         self.current_version = ""
 
@@ -102,7 +107,12 @@ class AppConfigProvider(BaseProvider):
 
 
 def get_app_config(
-    name: str, environment: str, application: Optional[str] = None, transform: Optional[str] = None, **sdk_options
+    name: str,
+    environment: str,
+    application: Optional[str] = None,
+    transform: Optional[str] = None,
+    force_fetch: bool = False,
+    **sdk_options
 ) -> Union[str, list, dict, bytes]:
     """
     Retrieve a configuration value from AWS App Config.
@@ -117,6 +127,8 @@ def get_app_config(
         Application of the configuration
     transform: str, optional
         Transforms the content from a JSON object ('json') or base64 binary string ('binary')
+    force_fetch: bool, optional
+        Force update even before a cached item has expired, defaults to False
     sdk_options: dict, optional
         Dictionary of options that will be passed to the Parameter Store get_parameter API call
 
@@ -155,4 +167,4 @@ def get_app_config(
 
     sdk_options["ClientId"] = CLIENT_ID
 
-    return DEFAULT_PROVIDERS["appconfig"].get(name, transform=transform, **sdk_options)
+    return DEFAULT_PROVIDERS["appconfig"].get(name, transform=transform, force_fetch=force_fetch, **sdk_options)
