@@ -3,7 +3,8 @@ from typing import Dict, List, Optional
 
 from pydantic import BaseModel, root_validator
 from pydantic.networks import HttpUrl
-from typing_extensions import Literal
+
+from ..types import Literal
 
 
 class SnsMsgAttributeModel(BaseModel):
